@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.)
 
-package v0_1
+package v0_3
 
 import (
 	"testing"
@@ -25,17 +25,19 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-// TestValidateFileContents tests that multiple sources (i.e. urls and inline) are not allowed but zero or one sources are
-func TestValidateFileContents(t *testing.T) {
+// TestValidateResource tests that multiple sources (i.e. urls and inline) are not allowed but zero or one sources are
+func TestValidateResource(t *testing.T) {
 	tests := []struct {
-		in  FileContents
-		out error
+		in      Resource
+		out     error
+		errPath path.ContextPath
 	}{
 		{},
+		// source specified
 		{
 			// contains invalid (by the validator's definition) combinations of fields,
 			// but the translator doesn't care and we can check they all get translated at once
-			FileContents{
+			Resource{
 				Source:      util.StrToPtr("http://example/com"),
 				Compression: util.StrToPtr("gzip"),
 				Verification: Verification{
@@ -43,9 +45,11 @@ func TestValidateFileContents(t *testing.T) {
 				},
 			},
 			nil,
+			path.New("yaml"),
 		},
+		// inline specified
 		{
-			FileContents{
+			Resource{
 				Inline:      util.StrToPtr("hello"),
 				Compression: util.StrToPtr("gzip"),
 				Verification: Verification{
@@ -53,9 +57,23 @@ func TestValidateFileContents(t *testing.T) {
 				},
 			},
 			nil,
+			path.New("yaml"),
 		},
+		// local specified
 		{
-			FileContents{
+			Resource{
+				Local:       util.StrToPtr("hello"),
+				Compression: util.StrToPtr("gzip"),
+				Verification: Verification{
+					Hash: util.StrToPtr("this isn't validated"),
+				},
+			},
+			nil,
+			path.New("yaml"),
+		},
+		// source + inline, invalid
+		{
+			Resource{
 				Source:      util.StrToPtr("data:,hello"),
 				Inline:      util.StrToPtr("hello"),
 				Compression: util.StrToPtr("gzip"),
@@ -64,15 +82,73 @@ func TestValidateFileContents(t *testing.T) {
 				},
 			},
 			common.ErrTooManyResourceSources,
+			path.New("yaml", "source"),
+		},
+		// source + local, invalid
+		{
+			Resource{
+				Source:      util.StrToPtr("data:,hello"),
+				Local:       util.StrToPtr("hello"),
+				Compression: util.StrToPtr("gzip"),
+				Verification: Verification{
+					Hash: util.StrToPtr("this isn't validated"),
+				},
+			},
+			common.ErrTooManyResourceSources,
+			path.New("yaml", "source"),
+		},
+		// inline + local, invalid
+		{
+			Resource{
+				Inline:      util.StrToPtr("hello"),
+				Local:       util.StrToPtr("hello"),
+				Compression: util.StrToPtr("gzip"),
+				Verification: Verification{
+					Hash: util.StrToPtr("this isn't validated"),
+				},
+			},
+			common.ErrTooManyResourceSources,
+			path.New("yaml", "inline"),
+		},
+		// source + inline + local, invalid
+		{
+			Resource{
+				Source:      util.StrToPtr("data:,hello"),
+				Inline:      util.StrToPtr("hello"),
+				Local:       util.StrToPtr("hello"),
+				Compression: util.StrToPtr("gzip"),
+				Verification: Verification{
+					Hash: util.StrToPtr("this isn't validated"),
+				},
+			},
+			common.ErrTooManyResourceSources,
+			path.New("yaml", "source"),
 		},
 	}
 
 	for i, test := range tests {
 		actual := test.in.Validate(path.New("yaml"))
 		expected := report.Report{}
-		// hardcode inline for now since that's the only place errors occur. Move into the
-		// test struct once there's more than one place
-		expected.AddOnError(path.New("yaml", "inline"), test.out)
+		expected.AddOnError(test.errPath, test.out)
+		assert.Equal(t, expected, actual, "#%d: bad report", i)
+	}
+}
+
+func TestValidateTree(t *testing.T) {
+	tests := []struct {
+		in  Tree
+		out error
+	}{
+		{
+			in:  Tree{},
+			out: common.ErrTreeNoLocal,
+		},
+	}
+
+	for i, test := range tests {
+		actual := test.in.Validate(path.New("yaml"))
+		expected := report.Report{}
+		expected.AddOnError(path.New("yaml"), test.out)
 		assert.Equal(t, expected, actual, "#%d: bad report", i)
 	}
 }
